You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by lu...@apache.org on 2012/02/25 17:42:02 UTC

svn commit: r1293646 - /commons/proper/math/trunk/src/main/java/org/apache/commons/math3/util/FastMathLiteralArrays.java

Author: luc
Date: Sat Feb 25 16:42:02 2012
New Revision: 1293646

URL: http://svn.apache.org/viewvc?rev=1293646&view=rev
Log:
reverted vetoed code change about cloning literal arrays

Modified:
    commons/proper/math/trunk/src/main/java/org/apache/commons/math3/util/FastMathLiteralArrays.java

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/util/FastMathLiteralArrays.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/util/FastMathLiteralArrays.java?rev=1293646&r1=1293645&r2=1293646&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/util/FastMathLiteralArrays.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/util/FastMathLiteralArrays.java Sat Feb 25 16:42:02 2012
@@ -6136,41 +6136,41 @@ class FastMathLiteralArrays {
     /**
      * Load "EXP_INT_A".
      *
      * @return the data array.
      */
     static double[] loadExpIntA() {
-        return EXP_INT_A;
+        return EXP_INT_A.clone();
     }
     /**
      * Load "EXP_INT_B".
      *
      * @return the data array.
      */
     static double[] loadExpIntB() {
-        return EXP_INT_B;
+        return EXP_INT_B.clone();
     }
     /**
      * Load "EXP_FRAC_A".
      *
      * @return the data array.
      */
     static double[] loadExpFracA() {
-        return EXP_FRAC_A;
+        return EXP_FRAC_A.clone();
     }
     /**
      * Load "EXP_FRAC_B".
      *
      * @return the data array.
      */
     static double[] loadExpFracB() {
-        return EXP_FRAC_B;
+        return EXP_FRAC_B.clone();
     }
     /**
      * Load "LN_MANT".
      *
      * @return the data array.
      */
     static double[][] loadLnMant() {
-        return LN_MANT;
+        return LN_MANT.clone();
     }
 }
@@ -6136,41 +6136,41 @@ class FastMathLiteralArrays {
      * Load "EXP_INT_A".
      *
-     * @return the data array.
+     * @return a clone of the data array.
      */
     static double[] loadExpIntA() {
@@ -6136,41 +6136,41 @@ class FastMathLiteralArrays {
      * Load "EXP_INT_B".
      *
-     * @return the data array.
+     * @return a clone of the data array.
      */
     static double[] loadExpIntB() {
@@ -6136,41 +6136,41 @@ class FastMathLiteralArrays {
      * Load "EXP_FRAC_A".
      *
-     * @return the data array.
+     * @return a clone of the data array.
      */
     static double[] loadExpFracA() {
@@ -6136,41 +6136,41 @@ class FastMathLiteralArrays {
      * Load "EXP_FRAC_B".
      *
-     * @return the data array.
+     * @return a clone of the data array.
      */
     static double[] loadExpFracB() {
@@ -6136,41 +6136,41 @@ class FastMathLiteralArrays {
      * Load "LN_MANT".
      *
-     * @return the data array.
+     * @return a clone of the data array.
      */
     static double[][] loadLnMant() {